/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef EVENTWATCHEREVENTCONTAINER_H
#define EVENTWATCHEREVENTCONTAINER_H

#include <qdom.h>
#include <qobject.h>

#include "lib/eventdata.h"

class QTimer;

namespace EventWatcher {

enum EventStates
{
    IsUnread,
    IsRead
};

class EventItem
{
public:
    EventItem() {}
    ~EventItem() {}
    EventStates state;
    EventData data; // contains information like caption, text, icon, date, action...
    uint id;
};

typedef QPtrList<EventItem> EventList;

class EventContainer : public QObject
{
Q_OBJECT
public:
    ~EventContainer();

public slots:
    void load();
    void save();

    const EventList getUnreadEvents() const;
    const EventList getReadEvents() const;
    const EventList getAllEvents() const;

    int countUnreadEvents();
    int countReadEvents();
    int countAllEvents();

    void addEvent(const EventData &data, const EventStates& state = IsUnread);
    bool eventAction(uint eventId);
    bool eventSetRead(uint eventId, bool read = true);
    bool eventDelete(uint eventId);

signals:
    void eventListChanged();
    void eventAdded(EventItem* eventItem);

private:
    friend EventContainer* eventContainer();
    EventContainer(QObject *parent = 0, const char *name = 0);

    QDomElement eventItemToNode( QDomDocument &d, const EventItem &i );

    QPtrList<EventItem> m_events;

    QTimer *m_saveTimer;
};

};

#endif
