/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef EVENTWATCHEREVENTVIEW_H
#define EVENTWATCHEREVENTVIEW_H

#include <qvaluelist.h>
#include <qsimplerichtext.h>

#include <qmime.h>
#include <qpainter.h>
#include <qpixmap.h>
#include <qscrollview.h>

namespace EventWatcher {

class EventItem;
class PlusMinusButton;

class EventViewItemBase;
typedef QValueList<EventViewItemBase*> EventViewItemList;

class EventView : public QScrollView
{
Q_OBJECT
    friend class EventViewItemBase;
public:
    EventView(QWidget *parent = 0, const char *name = 0);
    virtual ~EventView() {};

    virtual void insertItem(EventViewItemBase* item);
    virtual void removeItem(EventViewItemBase* item);
    virtual void clearItems();
    virtual EventViewItemList selectedItems();

    virtual EventViewItemBase* itemAt(const QPoint& pos);
    virtual QRect itemGeometry(EventViewItemBase* item);

    void toggleItem(EventViewItemBase* i);
    void selectItem(EventViewItemBase* i);
    void unselectItem(EventViewItemBase* i);
    void toggleRange(EventViewItemBase* a, EventViewItemBase* b);
    void selectItems();
    void unselectItems();

    QMimeSourceFactory* mimeSourceFactory() {  return QMimeSourceFactory::defaultFactory(); /*return m_mimeSource;*/ };
    bool loadMimeSource(const QString &source);

signals:
    void selectionChanged(int selectedItems);

protected:
    virtual void viewportResizeEvent(QResizeEvent *);

    virtual void contentsMousePressEvent( QMouseEvent * e );
    virtual void contentsMouseReleaseEvent( QMouseEvent * e );
    virtual void contentsMouseMoveEvent( QMouseEvent * e );

    virtual void drawContents ( QPainter * p, int clipx, int clipy, int clipw, int cliph );
    virtual void repaintItem( EventViewItemBase* item );
    virtual void updateGeometry();
    virtual void updateItemWidgets(EventViewItemBase* item, QRect itemRect);
private:
    EventViewItemList m_items;

    QPixmap m_bufferPixmap;
    QPainter m_bufferPainter;

    int m_selectedItems;
    bool m_mouseDown;
    EventViewItemBase* m_lastClickedItem;

//     QMimeSourceFactory m_mimeSource;
    QMap<QString,bool> m_mimeSourceMap; // holds the list of already loaded items
};

class EventViewItemBase
{
public:
    EventViewItemBase(EventView *ev);
    virtual ~EventViewItemBase();

    virtual EventView* eventView() const { return m_ev; }

    virtual EventViewItemBase* parentItem();
    virtual void setParentItem(EventViewItemBase* parent);
    virtual bool hasChildItems() const;
    virtual void insertChildItem(EventViewItemBase* item);
    virtual void removeChildItem(EventViewItemBase* item);
    virtual const EventViewItemList& childItems() const;
    virtual void setShowChildItems(bool show);
    virtual bool showChildItems() const;

    // some recursive methods handling child items...
    virtual void selectedItemsRecursive(EventViewItemList &list);
    virtual EventViewItemBase* itemAtRecursive(const QPoint& pos, int &height);
    virtual bool itemGeometryRecursive(QRect &geometry, EventViewItemBase* item, int &height);
    virtual void selectItemsRecursive();
    virtual void unselectItemsRecursive();
    virtual void drawContentsRecursive(QPainter *p, const QRect& clipRect, int &height);
    virtual void updateGeometryRecursive(int width, int &height);
    virtual void showItemWidgetsRecursive(bool show);

    virtual bool isSelectable() const = 0;
    virtual void setSelected(bool selected) { m_selected = selected; }
    virtual bool selected() const { return m_selected; }

    virtual void setGeometry(int width) {
        m_width = width;
        m_height = heightForWidth(width);
    }
    virtual int width() const { return m_width; }
    virtual int height() const { return m_height; }

    virtual bool hasActionWidget() const = 0;
    virtual bool hasControlWidget() const = 0;
    virtual bool hasKeepWidget() const = 0;
    virtual QRect actionWidgetGeometry() const = 0;
    virtual QRect controlWidgetGeometry() const = 0;
    virtual QRect keepWidgetGeometry() const = 0;
    virtual void setActionWidget(QWidget* aw) { m_actionWidget = aw; }
    virtual void setControlWidget(QWidget* cw) { m_controlWidget = cw; }
    virtual void setKeepWidget(QWidget* kw) { m_keepWidget = kw; }
    virtual QWidget *actionWidget() const { return m_actionWidget; }
    virtual QWidget *controlWidget() const { return m_controlWidget; }
    virtual QWidget *keepWidget() const { return m_keepWidget; }

    virtual void drawContents( QPainter* p, const QPoint& pos, const QRect& clipRect ) const = 0;

protected:
    virtual int heightForWidth(int width) const = 0;

private:
    EventView *m_ev;
    EventViewItemBase* m_parentItem;
    EventViewItemList m_childList;
    bool m_showChildItems;
    bool m_selected;
    int m_width;
    int m_height;
    QWidget *m_actionWidget;
    QWidget *m_controlWidget;
    QWidget *m_keepWidget;
};

};

#endif
