/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <kdebug.h>
#include <krun.h>
#include <kurl.h>

#include "eventdata.h"

namespace EventWatcher {

EventAction::EventAction()
{
    setAction(NoAction);
}

EventAction::EventAction(ActionType type, const QString &data, const QString &text)
{
    setAction(type,data,text);
}

EventAction::~EventAction()
{
}

void EventAction::setAction(ActionType type, const QString &data, const QString &text)
{
    m_type = type;
    m_data = data;
    m_text = text;
}

bool EventAction::performAction() const
{
    if(m_type == NoAction)
        return false;

    if(m_type == UrlAction) {
        KRun::runURL(KURL(m_data), "text/html");
        return true;
    } else {
        kdDebug() << "PerformAction() for this action type not implemented yet! m_data: " << m_data << endl;
        return false;
    }
    return false;
}

const ActionType& EventAction::actionType() const
{
    return m_type;
}

const QString& EventAction::actionData() const
{
    return m_data;
}

const QString& EventAction::actionText() const
{
    return m_text;
}

EventData::EventData() :
    m_time(QTime::currentTime()),
    m_date(QDate::currentDate()),
    m_shortTitle(QString::null),
    m_title(QString::null),
    m_text(QString::null),
    m_icon(QString::null),
    m_action(EventAction())
{
}

EventData::EventData(const QString &shortTitle, const QString &title, const QString &text, const QString &icon, const EventAction &action )
{
    setData(shortTitle,title,text,icon,action);
}

EventData::~EventData()
{
}

void EventData::setData(const QString &shortTitle, const QString &title, const QString &text, const QString &icon, const EventAction &action)
{
    setTime(QTime::currentTime());
    setDate(QDate::currentDate());
    setShortTitle(shortTitle);
    setTitle(title);
    setText(text);
    setIcon(icon);
    setAction(action);
}

void EventData::setDate(const QDate &date)
{
    m_date = date;
}

void EventData::setTime(const QTime &time)
{
    m_time = time;
}

void EventData::setShortTitle(const QString &str)
{
    m_shortTitle = str;
}

void EventData::setTitle(const QString &str)
{
    m_title = str;
}

void EventData::setText(const QString &str)
{
    m_text = str;
}

void EventData::setIcon(const QString &str)
{
    m_icon = str;
}

void EventData::setAction(const EventAction &action)
{
    m_action = action;
}

const QTime& EventData::time() const
{
    return m_time;
}

const QDate& EventData::date() const
{
    return m_date;
}

const QString& EventData::shortTitle() const
{
    return m_shortTitle;
}

const QString& EventData::title() const
{
    return m_title;
}

const QString& EventData::text() const
{
    return m_text;
}

const QString& EventData::icon() const
{
    return m_icon;
}

const EventAction EventData::action() const
{
    return m_action;
}

};
