/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qvaluelist.h>

#include <kapp.h>
#include <kconfig.h>
#include <kdebug.h>
#include <klibloader.h>
#include <kplugininfo.h> 
#include <ktrader.h>

#include "lib/plugin.h"
#include "pluginmanager.h"

namespace EventWatcher {

PluginManager* pluginManager()
{
    static PluginManager *mgr;
    if(mgr == 0) {
        mgr = new PluginManager();
    }
    return mgr;
}

PluginManager::PluginManager(QObject *parent, const char *name)
 : QObject(parent, name)
{
    fetchPluginList();
    readConfig();
}


PluginManager::~PluginManager()
{
    // delete plugins...
    for(PluginInfoList::Iterator it(m_pluginInfoList.begin()); it != m_pluginInfoList.end(); ++it) {
        unloadPlugin(*it);
    }
}

void PluginManager::loadEnabledPlugins()
{
    for(PluginInfoList::Iterator it(m_pluginInfoList.begin()); it != m_pluginInfoList.end(); ++it) {
        if( (*it).enabled ) {
            loadPlugin(*it);
        } else
        // make sure there are no disabled plugins running...
        {
            unloadPlugin(*it);
        }
    }
}

void PluginManager::unloadPlugins()
{
    for(PluginInfoList::Iterator it(m_pluginInfoList.begin()); it != m_pluginInfoList.end(); ++it) {
        unloadPlugin(*it);
    }
}

void PluginManager::loadPlugin(PluginInfo& info)
{
    if(info.loaded == false) {
        KLibFactory *factory = KLibLoader::self()->factory(info.service->library());
        info.plugin = static_cast<Plugin*>(factory->create(kapp, 0, "Plugin"));
        info.loaded = true;
        emit( pluginCreated(info.plugin) );
    }
}

void PluginManager::unloadPlugin(PluginInfo& info)
{
    if(info.loaded == true) {
        delete info.plugin;
        info.plugin = 0;

        info.loaded = false;
    }
}

// const PluginInfoList& PluginManager::pluginInfoList() const
// {
//     return m_pluginInfoList;
// }

void PluginManager::settingsChanged()
{
    readConfig();
    loadEnabledPlugins();
}

void PluginManager::fetchPluginList()
{
    unloadPlugins();
    m_pluginInfoList.clear();

    KTrader::OfferList traderResult = KTrader::self()->query("EventWatcher/Plugin");
    for(KTrader::OfferListIterator it(traderResult.begin()); it != traderResult.end(); ++it) {
        PluginInfo info;
        info.loaded = false;
        info.service = *it;
        info.plugin = 0;

        m_pluginInfoList.append(info);
    }
}

void PluginManager::readConfig()
{
    KConfig *config = kapp->config();
    config->setGroup("Plugins");
    for(PluginInfoList::Iterator it(m_pluginInfoList.begin()); it != m_pluginInfoList.end(); ++it) {
        (*it).enabled = config->readBoolEntry( (*it).service->library()+"Enabled",
                                               (*it).service->property("X-KDE-PluginInfo-EnabledByDefault").toBool() );
    }
}

};
#include "pluginmanager.moc"
