/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <dcopclient.h>
#include <kapplication.h>
#include <klocale.h>

#include "../../lib/eventdata.h"

#include "dcop.moc"
#include "dcop.h"

extern "C"
{
    void* init_eventwatcherdcopplugin()
    {
        KGlobal::locale()->insertCatalogue("eventwatcherdcop");
        return new Factory;
    }
}

Factory::Factory()
{
    s_instance = new KInstance( "eventwatcher" );
}

Factory::~Factory()
{
    delete s_instance;
}

QObject* Factory::createObject( QObject* parent, const char* name, const char*, const QStringList & )
{
  return new DcopPlugin( parent, name );
}

KInstance* Factory::s_instance = 0L;

DcopPlugin::DcopPlugin( QObject* parent, const char* name )
    : DCOPObject("EventInterface"), EventWatcher::Plugin ( parent, name )
      
{
    // Register with DCOP
    if ( kapp->dcopClient()->isRegistered() ) {
        kapp->dcopClient()->registerAs( "eventwatcher" , false );
        kapp->dcopClient()->setDefaultObject( objId() );
    }
}

DcopPlugin::~DcopPlugin()
{
}

void DcopPlugin::send(const QString &shortTitle, const QString &title)
{
    const EventWatcher::EventData data(shortTitle, title, QString::null, "dcopplugin");
    createEvent(data);
}

void DcopPlugin::send(const QString &shortTitle, const QString &title, const QString &text)
{
    const EventWatcher::EventData data(shortTitle, title, text, "dcopplugin");
    createEvent(data);
}

void DcopPlugin::send(const QString &shortTitle, const QString &title, const QString &text, const QString &icon)
{
    const EventWatcher::EventData data(shortTitle, title, text, icon);
    createEvent(data);
}

void DcopPlugin::settingsChanged()
{
    return; // nothing to do.
}

