/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef LOGCONFIG_H
#define LOGCONFIG_H

#include <qlistview.h> // QCheckListItem
#include <qobject.h>
#include <qvaluelist.h> 

class KConfig;
class ConfigDialog;
class SourceInfo;

typedef QValueList<SourceInfo> SourceList;

class LogConfig : public QObject
{
Q_OBJECT
public:
    LogConfig(QWidget* parent);
    ~LogConfig();

signals:
    void changed();

public slots:
    void slotAdd();
    void slotModify();
    void slotRemove();

    void load();
    void save();
    void defaults();

protected slots:
    void updateButtons();
    void listItemStateChanged(SourceInfo& i);
private:
    bool checkFile( QString url );
    void updateSourceListView();
    SourceList m_sourceList;
    KConfig *m_config;
    ConfigDialog *m_dialog;
};

class SourceInfo
{
public:
    QString url;
    QColor color;
    bool enabled;
    bool operator == (const SourceInfo& other)
    {
        return (url == other.url ) &&
                    (enabled == other.enabled);
    }
};

class SourceListItem : public QObject, public QCheckListItem
{
Q_OBJECT
public:
    SourceListItem(SourceInfo& info, QListView *parent);
    SourceListItem(SourceInfo& info, QListViewItem *parent);
    SourceInfo& info() const { return m_info; }

signals:
    void stateChanged(SourceInfo&);
protected:
    void updateColor();
    void stateChange(bool);
    
private:
    SourceInfo& m_info;
};

#endif
