/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef RSSCONFIG_H
#define RSSCONFIG_H

#include <qlistview.h> // QCheckListItem
#include <qobject.h>
#include <qvaluelist.h> 

#include <kurl.h>

class KConfig;
class ConfigDialog;
class SourceInfo;

typedef QMap<QString, SourceInfo> DefaultSourceList;
typedef QValueList<SourceInfo> CustomSourceList;

class RssConfig : public QObject
{
Q_OBJECT
public:
    RssConfig(QWidget* parent);
    ~RssConfig();

signals:
    void changed();

public slots:
    void slotAdd();
    void slotModify();
    void slotRemove();

    void load();
    void save();
    void defaults();

protected slots:
    void updateButtons();
private:
    void updateSourceListView();
    DefaultSourceList m_defaultSourceList;
    CustomSourceList m_customSourceList;
    KConfig *m_config;
    ConfigDialog *m_dialog;
};

class SourceInfo
{
public:
    QString name;
    KURL url;
    bool enabled;
    bool custom;
    bool operator == (const SourceInfo& other)
    {
        return (name == other.name) &&
                    (url.url() == other.url.url() ) &&
                    (enabled == other.enabled) &&
                    (custom == other.custom);
    }
};

class SourceListItem : public QObject, public QCheckListItem
{
Q_OBJECT
public:
    SourceListItem(SourceInfo& info, QListView *parent);
    SourceListItem(SourceInfo& info, QListViewItem *parent);
    SourceInfo& info() const { return m_info; }

signals:
    void stateChanged(SourceInfo&);
protected:
    void stateChange(bool);
    
private:
    SourceInfo& m_info;
};

#endif
