/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qtimer.h>

#include <kdebug.h>

#include <kconfig.h>
#include <kiconloader.h>
#include <klocale.h>

#include <rss/global.h>
#include <rss/loader.h>

#include "../../lib/eventview.h"

#include "rss.h"

extern "C"
{
    void* init_eventwatcherrssplugin()
    {
        KGlobal::locale()->insertCatalogue("eventwatcherrss");
        return new EventWatcherRss::Factory;
    }
}

namespace EventWatcherRss {

Factory::Factory()
{
    s_instance = new KInstance( "eventwatcher" );
}

Factory::~Factory()
{
    delete s_instance;
}

QObject* Factory::createObject( QObject* parent, const char* name, const char*, const QStringList & )
{
  return new RssPlugin( parent, name );
}

KInstance* Factory::s_instance = 0L;

RssPlugin::RssPlugin( QObject* parent, const char* name )
    : EventWatcher::Plugin ( parent, name )
{
    m_sources.setAutoDelete(true);

    readConfig();
    processSources();

    m_timer = new QTimer(this);
//     connect(m_timer, SIGNAL(timeout()), this, SLOT(sayHello()) );
    m_timer->start( m_interval * 1000, false ); // 1 msec = 1000 sec ...
}

RssPlugin::~RssPlugin()
{
}

void RssPlugin::settingsChanged()
{
    readConfig();
    m_timer->changeInterval( m_interval * 1000 ); // 1 msec = 1000 sec ...
}

// void Rss::sayHello()
// {
//     EventWatcher::EventView view(m_caption, m_text,
//                    KGlobal::iconLoader()->loadIcon("penguin",KIcon::Panel,KIcon::SizeSmall) );
//     createEvent(view);
// }

void RssPlugin::processSources()
{
    RSS::Loader *loader = RSS::Loader::create();
    connect(loader, SIGNAL(loadingComplete(Loader *, Document, Status)),
        this, SLOT(slotLoadingComplete(Loader *, Document, Status)));
    for(SourceInfoList::Iterator it = m_sources.begin(); it != m_sources.end(); ++it) {
        kdDebug() << "processing source: " << (*it)->name << endl;
        loader->loadFrom( (*it)->url , new RSS::FileRetriever );
    }
}

// void Rss::processSource(RSS::Loader *, RSS::Document doc, RSS::Status status)
// {
//     if (status != RSS::Success)
//         return;
// 
//     QString title = doc.title();
//     QString description = doc.description();
// }

void RssPlugin::readConfig()
{
    KConfig config("eventwatcherrsspluginrc");
    config.setGroup("General");
    m_interval = config.readNumEntry("Interval", 10);
    QStringList sources = config.readListEntry("Sources");
    m_sources.clear();
    for(QStringList::Iterator it = sources.begin(); it != sources.end(); ++it) {
        SourceInfo *info = new SourceInfo;
        config.setGroup( (*it) );
        info->url = KURL( config.readEntry( "Url" ) );
        info->name = (*it);
        // only append if the source is enabled...
        bool enabled = config.readBoolEntry( "Enabled", false );
        if(enabled)
            m_sources.append(info);
    }
}

};

#include "rss.moc"
