/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef EVENTWATCHERPLUGINSETTINGPAGE_H
#define EVENTWATCHERPLUGINSETTINGPAGE_H

#include <qvgroupbox.h>
#include <qlistview.h>
#include <qtooltip.h>
#include <qwidget.h>

#include <klistview.h>
#include <kservice.h>

namespace EventWatcher {

class PluginSettingInfo
{
public:
    KService::Ptr service;
    // plugin settings
    bool enabled;
};

typedef QValueList<PluginSettingInfo> PluginSettingInfoList;

class PluginListItem: public QCheckListItem
{
public:
    PluginListItem(PluginSettingInfo* info, QListView *parent);
    PluginSettingInfo* info() const { return m_info; }
  
protected:
    void stateChange(bool);
    
private:
    PluginSettingInfo* m_info;
    bool silentStateChange;
};

class PluginListView : public KListView
{
Q_OBJECT

friend class PluginListItem;

public:
    PluginListView(QWidget *parent = 0, const char *name = 0);
    virtual ~PluginListView();
    void updateList(); // refresh the data shown list view
    void updateConfig(); // write the settings from the list view to the configuration

signals:
    void stateChange(PluginListItem*, bool);

private:
    void fetchPluginList();
    PluginSettingInfoList m_pluginList;
    void readConfig();
    void writeConfig();
    void stateChanged(PluginListItem *, bool);
};

class PluginListViewToolTip : public QToolTip
{
public:
        PluginListViewToolTip( QWidget *parent, KListView *lv );
        void maybeTip( const QPoint &pos );
private:
        KListView *m_listView;
};

class PluginConfigDialog : public QVGroupBox
{
Q_OBJECT
public:
    PluginConfigDialog(QWidget *parent = 0, const char *name = 0);
    ~PluginConfigDialog();
    void setPluginService(const KService::Ptr& service);
signals:
    void signalSave();
    void signalDefaults();
    void changed();
public slots:
    void save();
    void defaults();
private:
    QObject *m_configObject;
    QString m_oldLibName;
};

class PluginSettingPage : public QWidget
{
Q_OBJECT
public:
    PluginSettingPage(QWidget *parent = 0, const char *name = 0);
    ~PluginSettingPage();
public slots:
    void pluginSelectionChanged();
    void pluginStateChange(PluginListItem*, bool enabled);

    void slotApply();
    void slotDefaults();
signals:
    void changed();
private:
    PluginListView *m_listView;
    PluginConfigDialog *m_config;
};

};

#endif
