/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qframe.h>
#include <qlayout.h>

#include <kiconloader.h>
#include <klocale.h>
#include <kmessagebox.h>

#include "settingsdialog.h"
#include "generalsettingpageimp.h"
#include "pluginsettingpage.h"

namespace EventWatcher {

SettingsDialog::SettingsDialog(QWidget *parent, const char *name, WFlags f)
 : KDialogBase(IconList, i18n("Preferences"), Default|Ok|Apply|Cancel, Ok, parent, name, f)
{
    QFrame *frame = addPage(i18n("General"), i18n("General"),
                            KGlobal::iconLoader()->loadIcon("gohome",KIcon::Panel,KIcon::SizeMedium) );
    QVBoxLayout *frameLayout = new QVBoxLayout( frame, 0, 0 );
    m_generalPage = new GeneralSettingPageImp(frame);
    frameLayout->addWidget(m_generalPage);

    frame = addPage(i18n("Plugins"), i18n("Plugin Manager"),
                            KGlobal::iconLoader()->loadIcon("input_devices_settings",KIcon::Panel,KIcon::SizeMedium) );
    frameLayout = new QVBoxLayout( frame, 0, 0 );
    m_pluginPage = new PluginSettingPage(frame);
    frameLayout->addWidget(m_pluginPage);

//     updateDialog();
    enableButtonApply(false);

    connect( m_generalPage, SIGNAL(changed()), this, SLOT(enableApply()) );
    connect( m_pluginPage, SIGNAL(changed()), this, SLOT(enableApply()) );
    connect( this, SIGNAL(defaultClicked()), m_generalPage, SLOT(slotDefaults()) );
    connect( this, SIGNAL(defaultClicked()), m_pluginPage, SLOT(slotDefaults()) );
}


SettingsDialog::~SettingsDialog()
{
}

// void SettingsDialog::updateDialog()
// {
//     m_pluginPage->slotUpdate();
// 
// 
// }

void SettingsDialog::updateConfiguration()
{
    m_generalPage->slotApply();
    m_pluginPage->slotApply();

    enableButtonApply(false);
}

// void SettingsDialog::slotDefault()
// {
//     if (KMessageBox::warningContinueCancel(this, i18n("This will set the default options in ALL pages of the preferences dialog! Continue?"), i18n("Set default options?"), i18n("Set defaults"))==KMessageBox::Continue)
//     {
//         m_pluginPage->slotDefault();
// 
//         enableApply();
//     }
// }

void SettingsDialog::slotApply() {
    updateConfiguration();
    emit settingsChanged(); // apply the preferences
    enableButtonApply(false);
};

void SettingsDialog::enableApply() {
    enableButtonApply(true);
};

};
#include "settingsdialog.moc"
