/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <qimage.h>
#include <qpainter.h>
#include <qpixmap.h>

#include <kdebug.h>
#include <kglobalsettings.h> 
#include <kiconloader.h>
#include <kpixmap.h>
#include <kpixmapeffect.h>

#include "systemtray.h"
#include "systemtray.moc"
#include "eventcontainer.h"

namespace EventWatcher {

SystemTray::SystemTray(QWidget* parent)
 : KSystemTray(parent)
{
    // update the icon...
    slotEventListChanged();
}


SystemTray::~SystemTray()
{
}

void SystemTray::slotEventListChanged()
{
    int unreadCount = eventContainer()->countUnreadEvents();

    if(unreadCount != 0)
    {
        QPixmap icon = loadIcon("eventwatcherlight");
        int pixmapWidth = icon.size().width();

        QString countString = QString::number( unreadCount );
        QFont countFont = KGlobalSettings::generalFont();
        countFont.setBold(true);

        // borrowed font size calculation code from KMail's systray.
        // decrease the size of the font for the number of unread messages if the
        // number doesn't fit into the available space
        float countFontSize = countFont.pointSizeFloat();
        QFontMetrics fm( countFont );
        int width = fm.width( countString );
        if( width > (pixmapWidth-4) )
        {
            countFontSize *= float( pixmapWidth-4 ) / float( width );
            countFont.setPointSizeFloat( countFontSize );
        }

        QPainter p( &icon );
        p.setFont( countFont );
        p.setPen( Qt::black );
        p.drawText( icon.rect(), Qt::AlignCenter, countString );

        setPixmap( icon );

    } else {
        setPixmap( loadIcon("eventwatchergray") );
    }
}


};
